@@ -1,6 +1,6 @@
 import warnings
 
-from bitcart import coins
+from bitcart import COINS
 
 from ..utils import mark_allowed_imports
 
@@ -9,8 +9,7 @@ def startup():
     context = {}
     with warnings.catch_warnings():  # for coins init without xpub
         warnings.simplefilter("ignore")
-        for coin_name in coins.__all__:
-            coin_class = getattr(coins, coin_name)
+        for coin_name, coin_class in COINS.items():
             context[coin_name] = mark_allowed_imports(coin_class)
             context[coin_name.lower()] = mark_allowed_imports(coin_class())
     return context
